# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_course_simple import ResponseWrapperCourseSimple

class TestResponseWrapperCourseSimple(unittest.TestCase):
    """ResponseWrapperCourseSimple unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperCourseSimple:
        """Test ResponseWrapperCourseSimple
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperCourseSimple`
        """
        model = ResponseWrapperCourseSimple()
        if include_optional:
            return ResponseWrapperCourseSimple(
                done = True,
                result = public_api_server_connector_v2.models.course_simple.CourseSimple(
                    title = '', 
                    image_id = '', 
                    description = '', 
                    url = '', 
                    payload = '', 
                    module_view_type = null, 
                    payment_type = null, 
                    course_access_type = null, 
                    number_days_access = 56, 
                    is_active = True, 
                    is_secret = True, 
                    is_archived = True, 
                    is_displayed_in_app = True, 
                    is_offline_downloadable = True, 
                    available_at = 56, 
                    launch_date_enabled = True, 
                    launch_date = 56, 
                    id = 56, 
                    portal_id = 56, 
                    order = 56, 
                    category = '', 
                    category_id = 56, 
                    sales_page_landing_id = 56, 
                    permalink = '', 
                    enable_double_optin = True, 
                    one_more_landing_id = 56, 
                    one_more_step_link = '', 
                    one_more_step_landing_id = 56, 
                    created_at_epoch = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperCourseSimple(
                done = True,
        )
        """

    def testResponseWrapperCourseSimple(self):
        """Test ResponseWrapperCourseSimple"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
