# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.file_upload_result import FileUploadResult
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ResponseWrapperFileUploadResult(BaseModel):
    """
    ResponseWrapperFileUploadResult
    """ # noqa: E501
    done: StrictBool = Field(description="Indicates if the operation was successful. True if successful, False otherwise. Always matches the HTTP status code. 2xx for success, 4xx or 5xx for failure.")
    result: Optional[FileUploadResult] = Field(default=None, description="The result of the operation, if successful. Should be an instance of the specified model. If the operation failed, this will always be null.")
    error: Optional[StrictStr] = Field(default=None, description="Error message if the operation failed. Should be a string describing the error. If the operation was successful, this will always be null.")
    __properties: ClassVar[List[str]] = ["done", "result", "error"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResponseWrapperFileUploadResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResponseWrapperFileUploadResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "done": obj.get("done"),
            "result": FileUploadResult.from_dict(obj["result"]) if obj.get("result") is not None else None,
            "error": obj.get("error")
        })
        return _obj


