# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.general_api import GeneralApi


class TestGeneralApi(unittest.IsolatedAsyncioTestCase):
    """GeneralApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = GeneralApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_key_auth_get_api_key_info(self) -> None:
        """Test case for api_key_auth_get_api_key_info

        Get Api Key Info
        """
        pass


if __name__ == '__main__':
    unittest.main()
