# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.courses_api import CoursesApi


class TestCoursesApi(unittest.IsolatedAsyncioTestCase):
    """CoursesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CoursesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_key_auth_add_course(self) -> None:
        """Test case for api_key_auth_add_course

        Add Course
        """
        pass

    async def test_api_key_auth_add_course_module(self) -> None:
        """Test case for api_key_auth_add_course_module

        Add Course Module
        """
        pass

    async def test_api_key_auth_add_course_module_lessons(self) -> None:
        """Test case for api_key_auth_add_course_module_lessons

        Add Course Module Lessons
        """
        pass

    async def test_api_key_auth_add_module_submodule(self) -> None:
        """Test case for api_key_auth_add_module_submodule

        Add Module Submodule
        """
        pass

    async def test_api_key_auth_count_courses(self) -> None:
        """Test case for api_key_auth_count_courses

        Count Courses
        """
        pass

    async def test_api_key_auth_delete_course(self) -> None:
        """Test case for api_key_auth_delete_course

        Delete Course
        """
        pass

    async def test_api_key_auth_delete_course_module(self) -> None:
        """Test case for api_key_auth_delete_course_module

        Delete Course Module
        """
        pass

    async def test_api_key_auth_delete_course_module_lesson(self) -> None:
        """Test case for api_key_auth_delete_course_module_lesson

        Delete Course Module Lesson
        """
        pass

    async def test_api_key_auth_delete_module_submodule(self) -> None:
        """Test case for api_key_auth_delete_module_submodule

        Delete Module Submodule
        """
        pass

    async def test_api_key_auth_get_course(self) -> None:
        """Test case for api_key_auth_get_course

        Get Course
        """
        pass

    async def test_api_key_auth_get_course_info(self) -> None:
        """Test case for api_key_auth_get_course_info

        Get Course Info
        """
        pass

    async def test_api_key_auth_get_course_module(self) -> None:
        """Test case for api_key_auth_get_course_module

        Get Course Module
        """
        pass

    async def test_api_key_auth_get_course_module_count(self) -> None:
        """Test case for api_key_auth_get_course_module_count

        Get Course Module Count
        """
        pass

    async def test_api_key_auth_get_course_module_info(self) -> None:
        """Test case for api_key_auth_get_course_module_info

        Get Course Module Info
        """
        pass

    async def test_api_key_auth_get_course_module_lesson(self) -> None:
        """Test case for api_key_auth_get_course_module_lesson

        Get Course Module Lesson
        """
        pass

    async def test_api_key_auth_get_course_module_lesson_content_blocks(self) -> None:
        """Test case for api_key_auth_get_course_module_lesson_content_blocks

        Get Course Module Lesson Content Blocks
        """
        pass

    async def test_api_key_auth_get_course_module_lesson_info(self) -> None:
        """Test case for api_key_auth_get_course_module_lesson_info

        Get Course Module Lesson Info
        """
        pass

    async def test_api_key_auth_get_course_module_lessons(self) -> None:
        """Test case for api_key_auth_get_course_module_lessons

        Get Course Module Lessons
        """
        pass

    async def test_api_key_auth_get_course_module_lessons_count(self) -> None:
        """Test case for api_key_auth_get_course_module_lessons_count

        Get Course Module Lessons Count
        """
        pass

    async def test_api_key_auth_get_course_modules(self) -> None:
        """Test case for api_key_auth_get_course_modules

        Get Course Modules
        """
        pass

    async def test_api_key_auth_get_courses(self) -> None:
        """Test case for api_key_auth_get_courses

        Get Courses
        """
        pass

    async def test_api_key_auth_get_module_submodule_count(self) -> None:
        """Test case for api_key_auth_get_module_submodule_count

        Get Module Submodule Count
        """
        pass

    async def test_api_key_auth_get_module_submodules(self) -> None:
        """Test case for api_key_auth_get_module_submodules

        Get Module Submodules
        """
        pass

    async def test_api_key_auth_get_submodule(self) -> None:
        """Test case for api_key_auth_get_submodule

        Get Submodule
        """
        pass

    async def test_api_key_auth_patch_course(self) -> None:
        """Test case for api_key_auth_patch_course

        Patch Course
        """
        pass

    async def test_api_key_auth_patch_course_module(self) -> None:
        """Test case for api_key_auth_patch_course_module

        Patch Course Module
        """
        pass

    async def test_api_key_auth_patch_course_module_lesson(self) -> None:
        """Test case for api_key_auth_patch_course_module_lesson

        Patch Course Module Lesson
        """
        pass

    async def test_api_key_auth_patch_course_module_lesson_attached_files(self) -> None:
        """Test case for api_key_auth_patch_course_module_lesson_attached_files

        Patch Course Module Lesson Attached Files
        """
        pass

    async def test_api_key_auth_patch_course_module_lesson_content_blocks(self) -> None:
        """Test case for api_key_auth_patch_course_module_lesson_content_blocks

        Patch Course Module Lesson Content Blocks
        """
        pass

    async def test_api_key_auth_patch_module_submodule(self) -> None:
        """Test case for api_key_auth_patch_module_submodule

        Patch Module Submodule
        """
        pass

    async def test_api_key_auth_update_course(self) -> None:
        """Test case for api_key_auth_update_course

        Update Course
        """
        pass

    async def test_api_key_auth_update_course_module(self) -> None:
        """Test case for api_key_auth_update_course_module

        Update Course Module
        """
        pass

    async def test_api_key_auth_update_course_module_lesson(self) -> None:
        """Test case for api_key_auth_update_course_module_lesson

        Update Course Module Lesson
        """
        pass

    async def test_api_key_auth_update_module_submodule(self) -> None:
        """Test case for api_key_auth_update_module_submodule

        Update Module Submodule
        """
        pass


if __name__ == '__main__':
    unittest.main()
